==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/script/navstevy.js <==


(function () {
    var nacteniOcekavanaZGetu = function (name) {
        return decodeURIComponent((new RegExp('[?|&]' + name + '=' + '([^&;]+?)(&|#|;|$)').exec(location.search) || [null, ''])[1]) || null;
    };
    var nastaveniDatumuACasuPrichodu = function () {
        var prichodCas = $("[name='prichod_time']");
        var prichodDatum = $("[name='prichod']");
        var odchodCas = $("[name='odchod_time']");
        var odchodDatum = $("[name='odchod']");
        var OcekavanyPrichodCas = $("[name='OcekavanyPrichod_time']");
        var formactionHodnota = $("[name='formaction']").val();
        var dt = new Date($.now());

        if (formactionHodnota === 'insert') {
            if (nacteniOcekavanaZGetu('ocekavana') === 0) {
                prichodDatum.val(dt.getDate() + "." + (dt.getMonth() + 1) + "." + dt.getFullYear());
                prichodCas.val(((dt.getHours() < 10) ? ("0" + dt.getHours()) : dt.getHours()) + ":" + ((dt.getMinutes() < 10) ? ("0" + dt.getMinutes()) : dt.getMinutes()));
            }
        }

        OcekavanyPrichodCas.on('dblclick', function () {
            OcekavanyPrichodCas.val(((dt.getHours() < 10) ? ("0" + dt.getHours()): dt.getHours()) + ":" + ((dt.getMinutes() < 10) ? ("0" + dt.getMinutes()): dt.getMinutes()));
        });

        odchodDatum.on('dblclick', function () {
            odchodDatum.val(dt.getDate() + "." + (dt.getMonth()+1) + "." + dt.getFullYear());
        });
        odchodCas.on('dblclick', function () {
            odchodCas.val(((dt.getHours() < 10) ? ("0" + dt.getHours()): dt.getHours()) + ":" + ((dt.getMinutes() < 10) ? ("0" + dt.getMinutes()): dt.getMinutes()));
        });
    };
    var vybraniPouzeDnesnihoDne = function () {
        var datum = $("[name='datum']");
        var vyberpocetdnu = $("[name='vyberpocetdnu']");

        datum.on('dblclick', function () {
            var dt = new Date($.now());

            datum.val(dt.getDate() + "." + (dt.getMonth()+1) + "." + dt.getFullYear());
            vyberpocetdnu.val("1");
            this.form.submit();
        });
    };

    var nactiMedium = function() {
        var idMedium = prompt(ron.translate("navstevy_nacist_cip_a_potvrdit"), "");

        if (!idMedium) {
            return;
        }

        var $externiZamestnanec = $("[name='externiZamestnanec']");
        $externiZamestnanec.find('option').each(function() {
            var $option = $(this);
            if($option.data('kod-karty') === idMedium){
                $externiZamestnanec.val($option.attr('value'));
            }
        });
    };

    var nacteniDokladuPomociDialogu = function () {
        var doklad = $("#nacteniDokladuPomociDialogu");
        var  obsah = '';

        doklad.on("click", function () {
            var dokladMedium = prompt(ron.translate("navstevy_nacist_doklad_a_potvrdit"), "");
            if (dokladMedium !== null || dokladMedium !== ""){
                obsah = dokladMedium;
            }

            parsovaniUdajuDokladu(obsah);
        })
    };


    var parsovaniUdajuDokladu = function (obsah) {
        var replaceGt = '';
        var IDMedia = '';
        var IDOP = '';
        var redukceGt = '';
        var radkyDokladu = '';
        var jmeno = '';
        var prijmeni = '';
        var doklad = '';
        var prijmeniInputPole = $("[name='prijmeni']");
        var jmenoInputPole = $("[name='jmeno']");
        var titulInputPole = $("[name='titul']");
        var dokladInputPole = $("[name='doklad']");
        var vzorID1 = '';
        var rozkladID2 = '';
        var externiZamestnanec = $("#externiZamestnanec");

        if (debugMode) {console.log("");}

        prijmeniInputPole.val("");
        jmenoInputPole.val("");
        titulInputPole.val("");
        dokladInputPole.val("");

        if ( /RON/i.test(obsah) ){
            replaceGt = obsah.replace(/</g,"");
            IDMedia = replaceGt.replace("RON", "");
            if (debugMode) {console.log("RON karticka");}
            if (debugMode) {console.log("ID media: " + IDMedia);}

            dokladInputPole.val(IDMedia);
        }

        if (/ID/i.test(obsah)){
            if (debugMode) {console.log("Obcansky prukaz");}

            redukceGt = obsah.replace(/<+/g,'<');
            radkyDokladu = redukceGt.split("<");

            IDOP = radkyDokladu[0].substr(5,radkyDokladu[0].length);
            vzorID1 = $.isNumeric(IDOP);

            if(vzorID1){
                if (debugMode) {console.log("Format OP ID1");}
                prijmeni = radkyDokladu[2].substr(1,radkyDokladu[2].length);
                jmeno = radkyDokladu[3];
                doklad = radkyDokladu[0].substr(5,radkyDokladu[0].length);
            } else {
                if (debugMode) {console.log("Format OP ID2");}
                prijmeni = radkyDokladu[0].substr(5,radkyDokladu[0].length);
                jmeno = radkyDokladu[1];
                rozkladID2 = radkyDokladu[2].substr(0,9);
                doklad = rozkladID2;
            }
            prijmeniInputPole.val(prijmeni.toLowerCase().replace(/\b[a-z]/g, function (velkePrvniPismeno) {
                return velkePrvniPismeno.toUpperCase();
            }));
            jmenoInputPole.val(jmeno.toLowerCase().replace(/\b[a-z]/g, function (velkePrvniPismeno) {
                return velkePrvniPismeno.toUpperCase();
            }));

            dokladInputPole.val(doklad);
        }
    };

    var najitNavstevuPomociIDMedia = function () {
        var tlacitkoProVlozeniIDMedium = $("#najit_navstevu_pomoci_id_medium");
        var jenMedium = $("[name='jenMedium']");
        var comboMedium = $("[name='medium']");
        var kod = '';

        tlacitkoProVlozeniIDMedium.on("click", function () {
            var IDMedium = prompt(ron.translate('navstevy_nacist_medium_a_potvrdit'), "");
            var nalezeno = false;

            if (IDMedium !== null || IDMedium !== "") {
                kod = IDMedium;
            }


            if (kod !== '' && kod !== undefined) {
                console.log('kod je zadany');

                comboMedium.find('option').each(function () {
                    console.log('kod hledam..');

                    console.log($(this).val());

                    if ($(this).val() === kod) {
                        console.log(kod);
                        console.log($(this).val());

                        jenMedium.prop('checked', true);
                        comboMedium.val(kod);
                        this.form.submit();
                    }
                })
            }
        })
    };


    var pripojeniCasuPrichoduASubmit = function () {
        var tlacitkoPripojitPrichod = $("#vlozit_prichod");
        var tlacitkoPripojitPrichodOdeslat = $("#vlozit_prichod_odeslat");
        var tlacitkoPripojitOdchod = $("#vlozit_odchod");
        var tlacitkoStorno = $("#tlacitko_storno");
        var prichodCas = $("[name='prichod_time']");
        var prichodDatum = $("[name='prichod']");
        var odchodCas = $("[name='odchod_time']");
        var odchodDatum = $("[name='odchod']");

        var OcekavanyPrichod = $("[name='OcekavanyPrichod']");
        var OcekavanyPrichod_time = $("[name='OcekavanyPrichod_time']");
        var prijmeni = $("[name='prijmeni']");
        var prijmeniJe = true;
        var datumJe = true;

        tlacitkoPripojitPrichodOdeslat.on('click', function () {
            var vyplnit = '';
            var dt = new Date($.now());
            prichodDatum.val(dt.getDate() + "." + (dt.getMonth() + 1) + "." + dt.getFullYear());
            prichodCas.val(((dt.getHours() < 10) ? ("0" + dt.getHours()) : dt.getHours()) + ":" + ((dt.getMinutes() < 10) ? ("0" + dt.getMinutes()) : dt.getMinutes()));

            if (otestujPole()) {
                this.form.submit();
            }
        });

         tlacitkoPripojitPrichod.on('click', function () {
            var dt = new Date($.now());
            prichodDatum.val(dt.getDate() + "." + (dt.getMonth() + 1) + "." + dt.getFullYear());
            prichodCas.val(((dt.getHours() < 10) ? ("0" + dt.getHours()) : dt.getHours()) + ":" + ((dt.getMinutes() < 10) ? ("0" + dt.getMinutes()) : dt.getMinutes()));
        });


        tlacitkoPripojitOdchod.on('click', function () {
            var dt = new Date($.now());
            odchodDatum.val(dt.getDate() + "." + (dt.getMonth() + 1) + "." + dt.getFullYear());
            odchodCas.val(((dt.getHours() < 10) ? ("0" + dt.getHours()) : dt.getHours()) + ":" + ((dt.getMinutes() < 10) ? ("0" + dt.getMinutes()) : dt.getMinutes()));
            this.form.submit();
        });

        tlacitkoStorno.on('click', function () {
            window.location.href = "?menuid=navstevy";
        });
    };

    var kontrolaVyplneniPoli = function () {
        $(":submit").click(function(){
             return otestujPole();
        });
    };


    var otestujPole = function () {
        var prijmeni = $("[name='prijmeni']");
        var vyplnit = '';
        var prichod = $("[name='prichod']");
        var prichod_time = $("[name='prichod_time']");
        var OcekavanyPrichod = $("[name='OcekavanyPrichod']");
        var OcekavanyPrichod_time = $("[name='OcekavanyPrichod_time']");
        var comboNavstiveneOsoby = $("[name='navstivenaOsoba'] option:selected");

        if(comboNavstiveneOsoby.length){
            if (comboNavstiveneOsoby.val().trim() === '') {  // osetreni formulare na prazdne jmeno
                vyplnit = comboNavstiveneOsoby.closest('select').data('title');
            }
        }

        if (prijmeni.length) {
            if (prijmeni.val().trim() === "") {  // osetreni formulare na prazdne jmeno
                vyplnit = vyplnit + ((vyplnit !== "") ? ", " : "") + prijmeni.data('title');
            }
        }

        if (vyplnit != '') {
            ron.showError(ron._('je_potreba_vyplnit') + ": " + vyplnit);
            return false;
        } else {
            return true;
        }
    };



    var
        navstivenaOsobaChange = function() {
            var hodnota = $(this).find("option:selected").attr('data-ron-telefon');
            $("#telefonNavstiveneOsoby").text(hodnota ? hodnota : '');
        },

        zamestnanecNavstevaChange = function() {
            var $option = $(this).find('option:selected');
            if ($option.length) {
                console.log($option);
                $("#prijmeni").val($option.data("prijmeni"));
                $("#jmeno").val($option.data("jmeno"));
                $("#titul").val($option.data("titul"));
            }
        },

        typNavstevyChange = function() {
            var radioTypNavstevyHodnota = $("[name='TypNavstevy']:checked").val();

            $("#row_zamestnanecNavsteva").toggle(radioTypNavstevyHodnota == "1");
        },

        drivejsiHodnotayChange = function() {
            var
                $this = $(this),
                selector = $this.data("input-selector");

            if (selector) {
                $(selector).val($this.val());
            }
        }
    ;

    $(function() {
        $("#form_navsteva")
            .on("change", "#navstivenaOsoba", navstivenaOsobaChange)
            .on("change", "#zamestnanecNavsteva", zamestnanecNavstevaChange)
            .on("change", "[name='TypNavstevy']", typNavstevyChange)
            .on("change", ".drivejsiHodnoty", drivejsiHodnotayChange)
            .on("click", "#nacteniID", nactiMedium)
            ;
        typNavstevyChange();
        kontrolaVyplneniPoli();
        nastaveniDatumuACasuPrichodu();
        vybraniPouzeDnesnihoDne();
        nacteniDokladuPomociDialogu();

        najitNavstevuPomociIDMedia();
        pripojeniCasuPrichoduASubmit();
        $("#hledaniJmena").focus();
    });

})();

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/script/navstevy.js <==


(function () {
    var nacteniOcekavanaZGetu = function (name) {
        return decodeURIComponent((new RegExp('[?|&]' + name + '=' + '([^&;]+?)(&|#|;|$)').exec(location.search) || [null, ''])[1]) || null;
    };
    var nastaveniDatumuACasuPrichodu = function () {
        var prichodCas = $("[name='prichod_time']");
        var prichodDatum = $("[name='prichod']");
        var odchodCas = $("[name='odchod_time']");
        var odchodDatum = $("[name='odchod']");
        var OcekavanyPrichodCas = $("[name='OcekavanyPrichod_time']");
        var formactionHodnota = $("[name='formaction']").val();
        var dt = new Date($.now());

        if (formactionHodnota === 'insert') {
            if (nacteniOcekavanaZGetu('ocekavana') === 0) {
                prichodDatum.val(dt.getDate() + "." + (dt.getMonth() + 1) + "." + dt.getFullYear());
                prichodCas.val(((dt.getHours() < 10) ? ("0" + dt.getHours()) : dt.getHours()) + ":" + ((dt.getMinutes() < 10) ? ("0" + dt.getMinutes()) : dt.getMinutes()));
            }
        }

        OcekavanyPrichodCas.on('dblclick', function () {
            OcekavanyPrichodCas.val(((dt.getHours() < 10) ? ("0" + dt.getHours()): dt.getHours()) + ":" + ((dt.getMinutes() < 10) ? ("0" + dt.getMinutes()): dt.getMinutes()));
        });

        odchodDatum.on('dblclick', function () {
            odchodDatum.val(dt.getDate() + "." + (dt.getMonth()+1) + "." + dt.getFullYear());
        });
        odchodCas.on('dblclick', function () {
            odchodCas.val(((dt.getHours() < 10) ? ("0" + dt.getHours()): dt.getHours()) + ":" + ((dt.getMinutes() < 10) ? ("0" + dt.getMinutes()): dt.getMinutes()));
        });
    };
    var vybraniPouzeDnesnihoDne = function () {
        var datum = $("[name='datum']");
        var vyberpocetdnu = $("[name='vyberpocetdnu']");

        datum.on('dblclick', function () {
            var dt = new Date($.now());

            datum.val(dt.getDate() + "." + (dt.getMonth()+1) + "." + dt.getFullYear());
            vyberpocetdnu.val("1");
            this.form.submit();
        });
    };

    var nactiMedium = function() {
        var idMedium = prompt(ron.translate("navstevy_nacist_cip_a_potvrdit"), "");

        if (!idMedium) {
            return;
        }

        var $externiZamestnanec = $("[name='externiZamestnanec']");
        $externiZamestnanec.find('option').each(function() {
            var $option = $(this);
            if($option.data('kod-karty') === idMedium){
                $externiZamestnanec.val($option.attr('value'));
            }
        });
    };

    var
        nacteniDokladuPomociDialogu = function () {
            var obsah = prompt(ron.translate("navstevy_nacist_doklad_a_potvrdit"), "");
            if (obsah) {
                parsovaniUdajuDokladu(obsah);
            }
        };


        parsovaniUdajuDokladu = function (obsah) {
            var
                $prijmeniInputPole = $("[name='prijmeni']"),
                $jmenoInputPole = $("[name='jmeno']"),
                $dokladInputPole = $("[name='doklad']");

            $prijmeniInputPole.val("");
            $jmenoInputPole.val("");
            $dokladInputPole.val("");
            $("[name='titul']").val("");

            if (obsah.substring(0, 3) == 'RON') {
                var
                    replaceGt = obsah.replace(/</g, ""),
                    IDMedia = replaceGt.replace("RON", "");

                ron.debugLog("RON karticka. ID media:", IDMedia);

                $dokladInputPole.val(IDMedia);
            } else {
                data = ronPortal.decodePersonalDocument(obsah.split(" ").join("\n"));

                $prijmeniInputPole.val(data.surname);
                $jmenoInputPole.val(data.name);

                $dokladInputPole.val(data.idNumber);
            }
        };

    var najitNavstevuPomociIDMedia = function () {
        var tlacitkoProVlozeniIDMedium = $("#najit_navstevu_pomoci_id_medium");
        var jenMedium = $("[name='jenMedium']");
        var comboMedium = $("[name='medium']");
        var kod = '';

        tlacitkoProVlozeniIDMedium.on("click", function () {
            var IDMedium = prompt(ron.translate('navstevy_nacist_medium_a_potvrdit'), "");
            var nalezeno = false;

            if (IDMedium !== null || IDMedium !== "") {
                kod = IDMedium;
            }


            if (kod !== '' && kod !== undefined) {
                console.log('kod je zadany');

                comboMedium.find('option').each(function () {
                    console.log('kod hledam..');

                    console.log($(this).val());

                    if ($(this).val() === kod) {
                        console.log(kod);
                        console.log($(this).val());

                        jenMedium.prop('checked', true);
                        comboMedium.val(kod);
                        this.form.submit();
                    }
                })
            }
        })
    };


    var pripojeniCasuPrichoduASubmit = function () {
        var tlacitkoPripojitPrichod = $("#vlozit_prichod");
        var tlacitkoPripojitPrichodOdeslat = $("#vlozit_prichod_odeslat");
        var tlacitkoPripojitOdchod = $("#vlozit_odchod");
        var tlacitkoStorno = $("#tlacitko_storno");
        var prichodCas = $("[name='prichod_time']");
        var prichodDatum = $("[name='prichod']");
        var odchodCas = $("[name='odchod_time']");
        var odchodDatum = $("[name='odchod']");

        var OcekavanyPrichod = $("[name='OcekavanyPrichod']");
        var OcekavanyPrichod_time = $("[name='OcekavanyPrichod_time']");
        var prijmeni = $("[name='prijmeni']");
        var prijmeniJe = true;
        var datumJe = true;

        tlacitkoPripojitPrichodOdeslat.on('click', function () {
            var vyplnit = '';
            var dt = new Date($.now());
            prichodDatum.val(dt.getDate() + "." + (dt.getMonth() + 1) + "." + dt.getFullYear());
            prichodCas.val(((dt.getHours() < 10) ? ("0" + dt.getHours()) : dt.getHours()) + ":" + ((dt.getMinutes() < 10) ? ("0" + dt.getMinutes()) : dt.getMinutes()));

            if (otestujPole()) {
                this.form.submit();
            }
        });

         tlacitkoPripojitPrichod.on('click', function () {
            var dt = new Date($.now());
            prichodDatum.val(dt.getDate() + "." + (dt.getMonth() + 1) + "." + dt.getFullYear());
            prichodCas.val(((dt.getHours() < 10) ? ("0" + dt.getHours()) : dt.getHours()) + ":" + ((dt.getMinutes() < 10) ? ("0" + dt.getMinutes()) : dt.getMinutes()));
        });


        tlacitkoPripojitOdchod.on('click', function () {
            var dt = new Date($.now());
            odchodDatum.val(dt.getDate() + "." + (dt.getMonth() + 1) + "." + dt.getFullYear());
            odchodCas.val(((dt.getHours() < 10) ? ("0" + dt.getHours()) : dt.getHours()) + ":" + ((dt.getMinutes() < 10) ? ("0" + dt.getMinutes()) : dt.getMinutes()));
            this.form.submit();
        });

        tlacitkoStorno.on('click', function () {
            window.location.href = "?menuid=navstevy";
        });
    };

    var kontrolaVyplneniPoli = function () {
        $(":submit").click(function(){
             return otestujPole();
        });
    };


    var otestujPole = function () {
        var prijmeni = $("[name='prijmeni']");
        var vyplnit = '';
        var prichod = $("[name='prichod']");
        var prichod_time = $("[name='prichod_time']");
        var OcekavanyPrichod = $("[name='OcekavanyPrichod']");
        var OcekavanyPrichod_time = $("[name='OcekavanyPrichod_time']");
        var comboNavstiveneOsoby = $("[name='navstivenaOsoba'] option:selected");

        if(comboNavstiveneOsoby.length){
            if (comboNavstiveneOsoby.val().trim() === '') {  // osetreni formulare na prazdne jmeno
                vyplnit = comboNavstiveneOsoby.closest('select').data('title');
            }
        }

        if (prijmeni.length) {
            if (prijmeni.val().trim() === "") {  // osetreni formulare na prazdne jmeno
                vyplnit = vyplnit + ((vyplnit !== "") ? ", " : "") + prijmeni.data('title');
            }
        }

        if (vyplnit != '') {
            ron.showError(ron._('je_potreba_vyplnit') + ": " + vyplnit);
            return false;
        } else {
            return true;
        }
    };



    var
        navstivenaOsobaChange = function() {
            var hodnota = $(this).find("option:selected").attr('data-ron-telefon');
            $("#telefonNavstiveneOsoby").text(hodnota ? hodnota : '');
        },

        zamestnanecNavstevaChange = function() {
            var $option = $(this).find('option:selected');
            if ($option.length) {
                console.log($option);
                $("#prijmeni").val($option.data("prijmeni"));
                $("#jmeno").val($option.data("jmeno"));
                $("#titul").val($option.data("titul"));
            }
        },

        typNavstevyChange = function() {
            var radioTypNavstevyHodnota = $("[name='TypNavstevy']:checked").val();

            $("#row_zamestnanecNavsteva").toggle(radioTypNavstevyHodnota == "1");
        },

        drivejsiHodnotayChange = function() {
            var
                $this = $(this),
                selector = $this.data("input-selector");

            if (selector) {
                $(selector).val($this.val());
            }
        }
    ;

    $(function() {
        $("#form_navsteva")
            .on("change", "#navstivenaOsoba", navstivenaOsobaChange)
            .on("change", "#zamestnanecNavsteva", zamestnanecNavstevaChange)
            .on("change", "[name='TypNavstevy']", typNavstevyChange)
            .on("change", ".drivejsiHodnoty", drivejsiHodnotayChange)
            .on("click", "#nacteniID", nactiMedium)
            ;
        typNavstevyChange();
        kontrolaVyplneniPoli();
        nastaveniDatumuACasuPrichodu();
        vybraniPouzeDnesnihoDne();

        najitNavstevuPomociIDMedia();
        pripojeniCasuPrichoduASubmit();

        $("#nacteniDokladuPomociDialogu").on("click", nacteniDokladuPomociDialogu);
        $("#hledaniJmena").focus();
    });

})();
